@@ -1,9 +1,9 @@
 package Data::Sah::Coerce::js::To_bool::From_str::common_words;
 
-# AUTHOR
-our $DATE = '2019-12-04'; # DATE
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-01-01'; # DATE
 our $DIST = 'Data-Sah-Coerce'; # DIST
-our $VERSION = '0.040'; # VERSION
+our $VERSION = '0.041'; # VERSION
 
 use 5.010001;
 use strict;
@@ -55,7 +55,7 @@ Data::Sah::Coerce::js::To_bool::From_str::common_words - Coerce from common true
 
 =head1 VERSION
 
-This document describes version 0.040 of Data::Sah::Coerce::js::To_bool::From_str::common_words (from Perl distribution Data-Sah-Coerce), released on 2019-12-04.
+This document describes version 0.041 of Data::Sah::Coerce::js::To_bool::From_str::common_words (from Perl distribution Data-Sah-Coerce), released on 2020-01-01.
 
 =head1 DESCRIPTION
 
@@ -90,7 +90,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
